@@ -32,3 +32,5 @@ class passwordObject(tldap.base.LDAPobject):
     passwordHistory = tldap.fields.CharField()
     passwordAllowChangeTime = tldap.fields.CharField()
     passwordGraceUserTime = tldap.fields.CharField()
+    nsRoleDN = tldap.fields.CharField()
+    nsRole = tldap.fields.CharField(max_instances=None)  # Readonly
